@@ -503,7 +503,7 @@ AnytoneSettingsExtension::AnytoneSettingsExtension(QObject *parent)
     _gpsSettings(new AnytoneGPSSettingsExtension(this)),
     _roamingSettings(new AnytoneRoamingSettingsExtension(this)),
     _bluetoothSettings(new AnytoneBluetoothSettingsExtension(this)),
-    _simplexRepeaterSettings(new AnytoneSimplexRepeaterSettingsExtension(this)),
+    _repeaterSettings(new AnytoneRepeaterSettingsExtension(this)),
     _satelliteSettings(new AnytoneSatelliteSettingsExtension(this)),
     _vfoScanType(VFOScanType::Time), _modeA(VFOMode::Memory), _modeB(VFOMode::Memory),
     _zoneA(), _zoneB(), _selectedVFO(VFO::A), _subChannel(true),
@@ -531,7 +531,7 @@ AnytoneSettingsExtension::AnytoneSettingsExtension(QObject *parent)
           this, &AnytoneSettingsExtension::modified);
   connect(_roamingSettings, &AnytoneRoamingSettingsExtension::modified,
           this, &AnytoneSettingsExtension::modified);
-  connect(_simplexRepeaterSettings, &AnytoneSimplexRepeaterSettingsExtension::modified,
+  connect(_repeaterSettings, &AnytoneRepeaterSettingsExtension::modified,
           this, &AnytoneSettingsExtension::modified);
     connect(_satelliteSettings, &AnytoneSatelliteSettingsExtension::modified,
           this, &AnytoneSettingsExtension::modified);
@@ -608,9 +608,9 @@ AnytoneSettingsExtension::bluetoothSettings() const {
   return _bluetoothSettings;
 }
 
-AnytoneSimplexRepeaterSettingsExtension *
-AnytoneSettingsExtension::simplexRepeaterSettings() const {
-  return _simplexRepeaterSettings;
+AnytoneRepeaterSettingsExtension *
+AnytoneSettingsExtension::repeaterSettings() const {
+  return _repeaterSettings;
 }
 
 AnytoneSatelliteSettingsExtension *
@@ -813,10 +813,12 @@ AnytoneSettingsExtension::setTBSTFrequency(Frequency Hz) {
   emit modified(this);
 }
 
+
 bool
 AnytoneSettingsExtension::proModeEnabled() const {
   return _proMode;
 }
+
 void
 AnytoneSettingsExtension::enableProMode(bool enable) {
   if (_proMode == enable)
@@ -825,10 +827,12 @@ AnytoneSettingsExtension::enableProMode(bool enable) {
   emit modified(this);
 }
 
+
 bool
 AnytoneSettingsExtension::maintainCallChannelEnabled() const {
   return _maintainCallChannel;
 }
+
 void
 AnytoneSettingsExtension::enableMaintainCallChannel(bool enable) {
   if (_maintainCallChannel == enable)
@@ -838,6 +842,21 @@ AnytoneSettingsExtension::enableMaintainCallChannel(bool enable) {
 }
 
 
+AnytoneSettingsExtension::FanControl
+AnytoneSettingsExtension::fan() const {
+  return _fan;
+}
+
+void
+AnytoneSettingsExtension::setFan(FanControl ctrl) {
+  if (_fan == ctrl)
+    return;
+  _fan = ctrl;
+  emit modified(this);
+}
+
+
+
 /* ********************************************************************************************* *
  * Implementation of AnytoneBootSettingsExtension
  * ********************************************************************************************* */
@@ -1044,7 +1063,9 @@ AnytoneKeySettingsExtension::AnytoneKeySettingsExtension(QObject *parent)
     _funcKeyBShort(KeyFunction::Voltage), _funcKeyBLong(KeyFunction::Call),
     _funcKeyCShort(KeyFunction::Power), _funcKeyCLong(KeyFunction::VOX),
     _funcKeyDShort(KeyFunction::Off), _funcKeyDLong(KeyFunction::Off),
-    _longPressDuration(Interval::fromSeconds(1)), _autoKeyLock(false), _knobLock(false), _keypadLock(false),
+    _funcKnobShort(KeyFunction::Off), _funcKnobLong(KeyFunction::Off),
+    _longPressDuration(Interval::fromSeconds(1)), _upDownFunction(UpDownKeyFunction::Channel),
+    _autoKeyLock(false), _knobLock(false), _keypadLock(false),
     _sideKeysLock(false), _forcedKeyLock(false)
 {
   // pass...
@@ -1290,6 +1311,34 @@ AnytoneKeySettingsExtension::setFuncKeyDLong(KeyFunction func) {
   emit modified(this);
 }
 
+
+AnytoneKeySettingsExtension::KeyFunction
+AnytoneKeySettingsExtension::funcKnobShort() const {
+  return _funcKnobShort;
+}
+
+void
+AnytoneKeySettingsExtension::setFuncKnobShort(KeyFunction func) {
+  if (_funcKnobShort == func)
+    return;
+  _funcKnobShort = func;
+  emit modified(this);
+}
+
+AnytoneKeySettingsExtension::KeyFunction
+AnytoneKeySettingsExtension::funcKnobLong() const {
+  return _funcKnobLong;
+}
+
+void
+AnytoneKeySettingsExtension::setFuncKnobLong(KeyFunction func) {
+  if (_funcKnobLong == func)
+    return;
+  _funcKnobLong = func;
+  emit modified(this);
+}
+
+
 Interval
 AnytoneKeySettingsExtension::longPressDuration() const {
   return _longPressDuration;
@@ -1302,6 +1351,21 @@ AnytoneKeySettingsExtension::setLongPressDuration(Interval ms) {
   emit modified(this);
 }
 
+
+AnytoneKeySettingsExtension::UpDownKeyFunction
+AnytoneKeySettingsExtension::upDownKeyFunction() const {
+  return _upDownFunction;
+}
+
+void
+AnytoneKeySettingsExtension::setUpDownKeyFunction(UpDownKeyFunction func) {
+  if (_upDownFunction == func)
+    return;
+  _upDownFunction = func;
+  emit modified(this);
+}
+
+
 bool
 AnytoneKeySettingsExtension::autoKeyLockEnabled() const {
   return _autoKeyLock;
@@ -1555,14 +1619,16 @@ AnytoneToneSettingsExtension::setKeyToneLevel(unsigned int level) {
  * ********************************************************************************************* */
 AnytoneDisplaySettingsExtension::AnytoneDisplaySettingsExtension(QObject *parent)
   : ConfigItem(parent), _displayFrequency(false), _brightness(5),
-    _volumeChangePrompt(true), _callEndPrompt(true),
-    _lastCallerDisplay(LastCallerDisplayMode::Both), _showClock(true), _showCall(true),
-    _callColor(Color::Orange), _language(Language::English), _dateFormat(DateFormat::DayFirst),
-    _showChannelNumber(true), _showGlobalChannelNumber(false), _showColorCode(true),
-    _showTimeSlot(true), _showChannelType(true), _showContact(true), _standbyTextColor(Color::White),
-    _standbyBackgroundColor(Color::Black), _showLastHeard(false), _backlightDurationTX(),
-    _backlightDurationRX(), _customChannelBackground(false), _channelNameColor(Color::Orange),
-    _channelBNameColor(Color::Orange), _zoneNameColor(Color::White), _zoneBNameColor(Color::White)
+  _volumeChangePrompt(true), _callEndPrompt(true),
+  _lastCallerDisplay(LastCallerDisplayMode::Both), _showClock(true), _showCall(true),
+  _callColor(Color::Orange), _language(Language::English), _dateFormat(DateFormat::DayFirst),
+  _showChannelNumber(true), _showGlobalChannelNumber(false), _showColorCode(true),
+  _showTimeSlot(true), _showChannelType(true), _showContact(true), _standbyTextColor(Color::White),
+  _standbyBackgroundColor(Color::Black), _showLastHeard(false),
+  _backlightDuration(Interval::infinity()), _backlightDurationTX(),
+  _backlightDurationRX(Interval::infinity()),
+  _customChannelBackground(false), _channelNameColor(Color::Orange),
+  _channelBNameColor(Color::Orange), _zoneNameColor(Color::White), _zoneBNameColor(Color::White)
 {
   // pass...
 }
@@ -1805,10 +1871,26 @@ AnytoneDisplaySettingsExtension::setStandbyBackgroundColor(Color color) {
   emit modified(this);
 }
 
+
+Interval
+AnytoneDisplaySettingsExtension::backlightDuration() const {
+  return _backlightDuration;
+}
+
+void
+AnytoneDisplaySettingsExtension::setBacklightDuration(Interval sec) {
+  if (_backlightDuration == sec)
+    return;
+  _backlightDuration = sec;
+  emit modified(this);
+}
+
+
 Interval
 AnytoneDisplaySettingsExtension::backlightDurationTX() const {
   return _backlightDurationTX;
 }
+
 void
 AnytoneDisplaySettingsExtension::setBacklightDurationTX(Interval sec) {
   if (_backlightDurationTX == sec)
@@ -1817,6 +1899,7 @@ AnytoneDisplaySettingsExtension::setBacklightDurationTX(Interval sec) {
   emit modified(this);
 }
 
+
 AnytoneDisplaySettingsExtension::Color
 AnytoneDisplaySettingsExtension::channelNameColor() const {
   return _channelNameColor;
@@ -1890,13 +1973,15 @@ AnytoneDisplaySettingsExtension::enableCustomChannelBackground(bool enable) {
 }
 
 
+
 /* ********************************************************************************************* *
  * Implementation of AnytoneAudioSettingsExtension
  * ********************************************************************************************* */
 AnytoneAudioSettingsExtension::AnytoneAudioSettingsExtension(QObject *parent)
   : ConfigItem(parent),  _voxDelay(), _recording(false), _voxSource(VoxSource::Both),
-    _maxVolume(3), _maxHeadPhoneVolume(3), _enhanceAudio(true), _muteDelay(Interval::fromMinutes(1)),
-    _enableAnalogMicGain(false), _analogMicGain(1)
+  _maxVolume(3), _maxHeadPhoneVolume(3), _enhanceAudio(true), _muteDelay(Interval::fromMinutes(1)),
+  _enableAnalogMicGain(false), _analogMicGain(1), _speaker(Speaker::Radio),
+  _handsetSpeaker(HandsetSpeakerSource::MainChannel), _handsetType(HandsetType::Anytone)
 {
   // pass...
 }
@@ -2018,6 +2103,49 @@ AnytoneAudioSettingsExtension::setFMMicGain(unsigned int gain) {
 }
 
 
+AnytoneAudioSettingsExtension::Speaker
+AnytoneAudioSettingsExtension::speaker() const {
+  return _speaker;
+}
+
+void
+AnytoneAudioSettingsExtension::setSpeaker(Speaker speaker) {
+  if (_speaker == speaker)
+    return;
+  _speaker = speaker;
+  emit modified(this);
+}
+
+
+AnytoneAudioSettingsExtension::HandsetSpeakerSource
+AnytoneAudioSettingsExtension::handsetSpeaker() const {
+  return _handsetSpeaker;
+}
+
+void
+AnytoneAudioSettingsExtension::setHandsetSpeaker(HandsetSpeakerSource src) {
+  if (_handsetSpeaker == src)
+    return;
+  _handsetSpeaker = src;
+  emit modified(this);
+}
+
+
+AnytoneAudioSettingsExtension::HandsetType
+AnytoneAudioSettingsExtension::handsetType() const {
+  return _handsetType;
+}
+
+void
+AnytoneAudioSettingsExtension::setHandsetType(HandsetType type) {
+  if (_handsetType == type)
+    return;
+  _handsetType = type;
+  emit modified(this);
+}
+
+
+
 /* ********************************************************************************************* *
  * Implementation of AnytoneMenuSettingsExtension
  * ********************************************************************************************* */
@@ -2285,15 +2413,301 @@ AnytoneAutoRepeaterOffsetList::AnytoneAutoRepeaterOffsetList(QObject *parent)
 }
 
 
+
+/* ********************************************************************************************* *
+ * Implementation of AnytoneBluetoothHandsetSettingsExtension
+ * ********************************************************************************************* */
+AnytoneBluetoothHandsetSettingsExtension::AnytoneBluetoothHandsetSettingsExtension(QObject *parent)
+  : ConfigItem{parent}, _shutdown(true), _volumeLevelA(0), _volumeLevelB(0), _micGain(1),
+  _squelch(1), _txNoiseReduction(0), _voxLevel(0), _voxDelay(Interval::null()),
+  _funcKeyAShort(AnytoneKeySettingsExtension::KeyFunction::Off),
+  _funcKeyBShort(AnytoneKeySettingsExtension::KeyFunction::Off),
+  _funcKeyCShort(AnytoneKeySettingsExtension::KeyFunction::Off),
+  _funcKeyALong(AnytoneKeySettingsExtension::KeyFunction::Off),
+  _funcKeyBLong(AnytoneKeySettingsExtension::KeyFunction::Off),
+  _funcKeyCLong(AnytoneKeySettingsExtension::KeyFunction::Off),
+  _funcKeyAVeryLong(AnytoneKeySettingsExtension::KeyFunction::Off),
+  _funcKeyBVeryLong(AnytoneKeySettingsExtension::KeyFunction::Off),
+  _funcKeyCVeryLong(AnytoneKeySettingsExtension::KeyFunction::Off),
+  _backlight(Interval::fromSeconds(30))
+{
+  // pass...
+}
+
+
+ConfigItem *
+AnytoneBluetoothHandsetSettingsExtension::clone() const {
+  auto obj = new AnytoneBluetoothHandsetSettingsExtension();
+  if (! obj->copy(*this)) {
+    delete obj;
+    return nullptr;
+  }
+  return obj;
+}
+
+
+bool
+AnytoneBluetoothHandsetSettingsExtension::shutdownEnabled() const {
+  return _shutdown;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::enableShutdown(bool enable) {
+  if (_shutdown == enable)
+    return;
+  _shutdown = enable;
+  emit modified(this);
+}
+
+
+unsigned int
+AnytoneBluetoothHandsetSettingsExtension::volumeLevelA() const {
+  return _volumeLevelA;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setVolumeLevelA(unsigned int level) {
+  level = std::min(10U, level);
+  if (_volumeLevelA == level)
+    return;
+  _volumeLevelA = level;
+  emit modified(this);
+}
+
+
+unsigned int
+AnytoneBluetoothHandsetSettingsExtension::volumeLevelB() const {
+  return _volumeLevelB;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setVolumeLevelB(unsigned int level) {
+  level = std::min(10U, level);
+  if (_volumeLevelB == level)
+    return;
+  _volumeLevelB = level;
+  emit modified(this);
+}
+
+
+unsigned int
+AnytoneBluetoothHandsetSettingsExtension::micGain() const {
+  return _micGain;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setMicGain(unsigned int gain) {
+  gain = std::max(1u, std::min(10U, gain));
+  if (_micGain == gain)
+    return;
+  _micGain = gain;
+  emit modified(this);
+}
+
+
+unsigned int
+AnytoneBluetoothHandsetSettingsExtension::squelch() const {
+  return _squelch;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setSquelch(unsigned int level) {
+  level = std::min(10U, level);
+  if (_squelch == level)
+    return;
+  _squelch = level;
+  emit modified(this);
+}
+
+
+unsigned int
+AnytoneBluetoothHandsetSettingsExtension::txNoiseReduction() const {
+  return _txNoiseReduction;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setTxNoiseReduction(unsigned int level) {
+  level = std::max(10U, level);
+  if (_txNoiseReduction == level)
+    return;
+  _txNoiseReduction = level;
+  emit modified(this);
+}
+
+
+unsigned int
+AnytoneBluetoothHandsetSettingsExtension::voxLevel() const {
+  return _voxLevel;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setVoxLevel(unsigned int level) {
+  level = std::min(10U, level);
+  if (_voxLevel == level)
+    return;
+  _voxLevel = level;
+  emit modified(this);
+}
+
+
+Interval
+AnytoneBluetoothHandsetSettingsExtension::voxDelay() const {
+  return _voxDelay;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setVoxDelay(Interval delay) {
+  if (_voxDelay == delay)
+    return;
+  _voxDelay = delay;
+  emit modified(this);
+}
+
+
+AnytoneKeySettingsExtension::KeyFunction
+AnytoneBluetoothHandsetSettingsExtension::funcKeyAShort() const {
+  return _funcKeyAShort;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setFuncKeyAShort(AnytoneKeySettingsExtension::KeyFunction func) {
+  if (_funcKeyAShort == func)
+    return;
+  _funcKeyAShort = func;
+  emit modified(this);
+}
+
+AnytoneKeySettingsExtension::KeyFunction
+AnytoneBluetoothHandsetSettingsExtension::funcKeyBShort() const {
+  return _funcKeyBShort;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setFuncKeyBShort(AnytoneKeySettingsExtension::KeyFunction func) {
+  if (_funcKeyBShort == func)
+    return;
+  _funcKeyBShort = func;
+  emit modified(this);
+}
+
+AnytoneKeySettingsExtension::KeyFunction
+AnytoneBluetoothHandsetSettingsExtension::funcKeyCShort() const {
+  return _funcKeyCShort;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setFuncKeyCShort(AnytoneKeySettingsExtension::KeyFunction func) {
+  if (_funcKeyCShort == func)
+    return;
+  _funcKeyCShort = func;
+  emit modified(this);
+}
+
+AnytoneKeySettingsExtension::KeyFunction
+AnytoneBluetoothHandsetSettingsExtension::funcKeyALong() const {
+  return _funcKeyALong;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setFuncKeyALong(AnytoneKeySettingsExtension::KeyFunction func) {
+  if (_funcKeyALong == func)
+    return;
+  _funcKeyALong = func;
+  emit modified(this);
+}
+
+AnytoneKeySettingsExtension::KeyFunction
+AnytoneBluetoothHandsetSettingsExtension::funcKeyBLong() const {
+  return _funcKeyBLong;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setFuncKeyBLong(AnytoneKeySettingsExtension::KeyFunction func) {
+  if (_funcKeyBLong == func)
+    return;
+  _funcKeyBLong = func;
+  emit modified(this);
+}
+
+AnytoneKeySettingsExtension::KeyFunction
+AnytoneBluetoothHandsetSettingsExtension::funcKeyCLong() const {
+  return _funcKeyCLong;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setFuncKeyCLong(AnytoneKeySettingsExtension::KeyFunction func) {
+  if (_funcKeyCLong == func)
+    return;
+  _funcKeyCLong = func;
+  emit modified(this);
+}
+
+AnytoneKeySettingsExtension::KeyFunction
+AnytoneBluetoothHandsetSettingsExtension::funcKeyAVeryLong() const {
+  return _funcKeyAVeryLong;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setFuncKeyAVeryLong(AnytoneKeySettingsExtension::KeyFunction func) {
+  if (_funcKeyAVeryLong == func)
+    return;
+  _funcKeyAVeryLong = func;
+  emit modified(this);
+}
+
+AnytoneKeySettingsExtension::KeyFunction
+AnytoneBluetoothHandsetSettingsExtension::funcKeyBVeryLong() const {
+  return _funcKeyBVeryLong;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setFuncKeyBVeryLong(AnytoneKeySettingsExtension::KeyFunction func) {
+  if (_funcKeyBVeryLong == func)
+    return;
+  _funcKeyBVeryLong = func;
+  emit modified(this);
+}
+
+AnytoneKeySettingsExtension::KeyFunction
+AnytoneBluetoothHandsetSettingsExtension::funcKeyCVeryLong() const {
+  return _funcKeyCVeryLong;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setFuncKeyCVeryLong(AnytoneKeySettingsExtension::KeyFunction func) {
+  if (_funcKeyCVeryLong == func)
+    return;
+  _funcKeyCVeryLong = func;
+  emit modified(this);
+}
+
+Interval
+AnytoneBluetoothHandsetSettingsExtension::backlight() const {
+  return _backlight;
+}
+
+void
+AnytoneBluetoothHandsetSettingsExtension::setBacklight(Interval dur) {
+  if (_backlight == dur)
+    return;
+  _backlight = dur;
+  emit modified(this);
+}
+
+
+
 /* ********************************************************************************************* *
  * Implementation of AnytoneBluetoothSettingsExtension
  * ********************************************************************************************* */
 AnytoneBluetoothSettingsExtension::AnytoneBluetoothSettingsExtension(QObject *parent)
-  : ConfigItem(parent), _bluetoothEnabled(false), _pttLatch(false),
-    _pttSleep(Interval::fromMilliseconds(0)), _internalMic(false), _internalSpeaker(false),
-    _micGain(0), _speakerGain(0), _holdDuration(), _holdDelay()
+  : ConfigItem(parent),
+  _handset(new AnytoneBluetoothHandsetSettingsExtension(this)),
+  _bluetoothEnabled(false), _pttLatch(false), _pttSleep(Interval::fromMilliseconds(0)),
+  _internalMic(false), _internalSpeaker(false), _micGain(0), _speakerGain(0), _holdDuration(),
+  _holdDelay()
 {
-  // pass...
+  connect(_handset, &AnytoneBluetoothHandsetSettingsExtension::modified,
+          this, &AnytoneBluetoothSettingsExtension::modified);
 }
 
 ConfigItem *
@@ -2318,6 +2732,11 @@ AnytoneBluetoothSettingsExtension::enablePTTLatch(bool enable) {
   emit modified(this);
 }
 
+AnytoneBluetoothHandsetSettingsExtension *
+AnytoneBluetoothSettingsExtension::handset() const {
+  return _handset;
+}
+
 bool
 AnytoneBluetoothSettingsExtension::bluetoothEnabled() const {
   return _bluetoothEnabled;
@@ -2425,15 +2844,16 @@ AnytoneBluetoothSettingsExtension::setHoldDelay(const Interval &dur) {
 /* ********************************************************************************************* *
  * Implementation of AnytoneSimplexRepeaterSettingsExtension
  * ********************************************************************************************* */
-AnytoneSimplexRepeaterSettingsExtension::AnytoneSimplexRepeaterSettingsExtension(QObject *parent)
-  : ConfigItem(parent), _enabled(false), _monitor(false), _timeSlot(TimeSlot::Channel)
+AnytoneRepeaterSettingsExtension::AnytoneRepeaterSettingsExtension(QObject *parent)
+  : ConfigItem(parent), _enabled(false), _monitor(false), _timeSlot(TimeSlot::Channel),
+  _secTimeSlot(TimeSlot::Channel), _colorCode(ColorCode::Ignored)
 {
   // pass...
 }
 
 ConfigItem *
-AnytoneSimplexRepeaterSettingsExtension::clone() const {
-  AnytoneSimplexRepeaterSettingsExtension *ext = new AnytoneSimplexRepeaterSettingsExtension();
+AnytoneRepeaterSettingsExtension::clone() const {
+  AnytoneRepeaterSettingsExtension *ext = new AnytoneRepeaterSettingsExtension();
   if (! ext->copy(*this)) {
     ext->deleteLater();
     return nullptr;
@@ -2442,11 +2862,11 @@ AnytoneSimplexRepeaterSettingsExtension::clone() const {
 }
 
 bool
-AnytoneSimplexRepeaterSettingsExtension::enabled() const {
+AnytoneRepeaterSettingsExtension::enabled() const {
   return _enabled;
 }
 void
-AnytoneSimplexRepeaterSettingsExtension::enable(bool enable) {
+AnytoneRepeaterSettingsExtension::enable(bool enable) {
   if (_enabled == enable)
     return;
   _enabled = enable;
@@ -2454,23 +2874,23 @@ AnytoneSimplexRepeaterSettingsExtension::enable(bool enable) {
 }
 
 bool
-AnytoneSimplexRepeaterSettingsExtension::monitorEnabled() const {
+AnytoneRepeaterSettingsExtension::monitorEnabled() const {
   return _monitor;
 }
 void
-AnytoneSimplexRepeaterSettingsExtension::enableMonitor(bool enable) {
+AnytoneRepeaterSettingsExtension::enableMonitor(bool enable) {
   if (_monitor == enable)
     return;
   _monitor = enable;
   emit modified(this);
 }
 
-AnytoneSimplexRepeaterSettingsExtension::TimeSlot
-AnytoneSimplexRepeaterSettingsExtension::timeSlot() const {
+AnytoneRepeaterSettingsExtension::TimeSlot
+AnytoneRepeaterSettingsExtension::timeSlot() const {
   return _timeSlot;
 }
 void
-AnytoneSimplexRepeaterSettingsExtension::setTimeSlot(TimeSlot ts) {
+AnytoneRepeaterSettingsExtension::setTimeSlot(TimeSlot ts) {
   if (_timeSlot == ts)
     return;
   _timeSlot = ts;
@@ -2478,6 +2898,33 @@ AnytoneSimplexRepeaterSettingsExtension::setTimeSlot(TimeSlot ts) {
 }
 
 
+AnytoneRepeaterSettingsExtension::TimeSlot
+AnytoneRepeaterSettingsExtension::secTimeSlot() const {
+  return _secTimeSlot;
+}
+void
+AnytoneRepeaterSettingsExtension::setSecTimeSlot(TimeSlot ts) {
+  if (_secTimeSlot == ts)
+    return;
+  _secTimeSlot = ts;
+  emit modified(this);
+}
+
+
+AnytoneRepeaterSettingsExtension::ColorCode
+AnytoneRepeaterSettingsExtension::colorCode() const {
+  return _colorCode;
+}
+
+void
+AnytoneRepeaterSettingsExtension::setColorCode(ColorCode code) {
+  if (_colorCode == code)
+    return;
+  _colorCode = code;
+  emit modified(this);
+}
+
+
 
 /* ********************************************************************************************* *
  * Implementation of AnytoneSatelliteSettingsExtension
