@@ -29,9 +29,9 @@ DM1701::limits() const {
 RadioInfo
 DM1701::defaultRadioInfo() {
   return RadioInfo(
-        RadioInfo::DM1701, "dm1701", "DM-1701", "Baofeng", TyTInterface::interfaceInfo(),
+        RadioInfo::DM1701, "dm1701", "DM-1701", "Baofeng", {TyTInterface::interfaceInfo()},
         QList<RadioInfo>{
-          RadioInfo(RadioInfo::RT84, "rt84", "RT84", "Retevis", TyTInterface::interfaceInfo())
+          RadioInfo(RadioInfo::RT84, "rt84", "RT84", "Retevis", {TyTInterface::interfaceInfo()})
         });
 }
 
