@@ -19,6 +19,11 @@ MD390Limits::MD390Limits(const std::initializer_list<std::pair<Frequency,Frequen
   _callSignDBImplemented  = false;
   _numCallSignDBEntries   = 0;
 
+  // Define limits for satellite config
+  _hasSatelliteConfig          = false;
+  _satelliteConfigImplemented  = false;
+  _numSatellites               = 0;
+
   add("settings", new RadioLimitItem {
         { "introLine1", new RadioLimitString(-1, 10, RadioLimitString::Unicode) },
         { "introLine2", new RadioLimitString(-1, 10, RadioLimitString::Unicode) },
@@ -38,7 +43,7 @@ MD390Limits::MD390Limits(const std::initializer_list<std::pair<Frequency,Frequen
   add("radioIDs", new RadioLimitList{
         { DMRRadioID::staticMetaObject, 1, 1, new RadioLimitObject {
             {"name", new RadioLimitString(1, 16, RadioLimitString::Unicode) },
-            {"id", new RadioLimitUInt(0, 16777215)}
+            {"number", new RadioLimitDMRId(RadioLimitIssue::Severity::Critical)}
           } }
       } );
 
@@ -52,7 +57,7 @@ MD390Limits::MD390Limits(const std::initializer_list<std::pair<Frequency,Frequen
                 (unsigned) DMRContact::GroupCall,
                 (unsigned) DMRContact::AllCall
               }},
-            { "number", new RadioLimitUInt(0, 16777215) }
+            { "number", new RadioLimitDMRId(RadioLimitIssue::Severity::Hint) }
           } },
         { DTMFContact::staticMetaObject, -1, -1, new RadioLimitIgnored() }
       } );
@@ -71,7 +76,7 @@ MD390Limits::MD390Limits(const std::initializer_list<std::pair<Frequency,Frequen
           { FMChannel::staticMetaObject,
             new RadioLimitObject {
               {"name", new RadioLimitString(1, 16, RadioLimitString::Unicode)},
-              {"rxFrequency", new RadioLimitFrequencies(freqRanges, true)},
+              {"rxFrequency", new RadioLimitFrequencies(freqRanges, RadioLimitIssue::Severity::Critical)},
               {"txFrequency", new RadioLimitTransmitFrequencies(freqRanges)},
               {"power", new RadioLimitEnum{unsigned(Channel::Power::Low), unsigned(Channel::Power::High)}},
               {"timeout", new RadioLimitUInt(0, -1, std::numeric_limits<unsigned>::max())},
@@ -95,7 +100,7 @@ MD390Limits::MD390Limits(const std::initializer_list<std::pair<Frequency,Frequen
           { DMRChannel::staticMetaObject,
             new RadioLimitObject {
               {"name", new RadioLimitString(1, 16, RadioLimitString::Unicode)},
-              {"rxFrequency", new RadioLimitFrequencies(freqRanges, true)},
+              {"rxFrequency", new RadioLimitFrequencies(freqRanges, RadioLimitIssue::Severity::Critical)},
               {"txFrequency", new RadioLimitTransmitFrequencies(freqRanges)},
               {"power", new RadioLimitEnum {
                  unsigned(Channel::Power::Low),
@@ -135,7 +140,7 @@ MD390Limits::MD390Limits(const std::initializer_list<std::pair<Frequency,Frequen
 
   /* Define limits for scan lists. */
   add("scanlists", new RadioLimitList(
-        ScanList::staticMetaObject, 1, 250, new RadioLimitObject{
+        ScanList::staticMetaObject, 0, 250, new RadioLimitObject{
           { "name", new RadioLimitString(1, 16, RadioLimitString::Unicode) },
           { "primary", new RadioLimitObjRef(Channel::staticMetaObject, true) },
           { "secondary", new RadioLimitObjRef(Channel::staticMetaObject, true) },
@@ -144,13 +149,13 @@ MD390Limits::MD390Limits(const std::initializer_list<std::pair<Frequency,Frequen
         }) );
 
   /* Define limits for positioning systems. */
-  add("positioning", new RadioLimitList(
-        GPSSystem::staticMetaObject, 0, 16, new RadioLimitObject {
+  add("positioning", new RadioLimitList({
+        { GPSSystem::staticMetaObject, 0, 16, new RadioLimitObject {
           { "name", new RadioLimitStringIgnored() },
           { "period", new RadioLimitUInt(0, 7650) },
           { "contact", new RadioLimitObjRef(DMRContact::staticMetaObject, false) },
-          { "revert", new RadioLimitObjRef(DMRChannel::staticMetaObject, true) }
-        } ) );
+          { "revert", new RadioLimitObjRef({SelectedChannel::staticMetaObject, DMRChannel::staticMetaObject}, true) } } },
+        { APRSSystem::staticMetaObject, 0, -1, new RadioLimitIgnored() } } ) );
 
   /* Check encryption keys. */
   add("commercial", new RadioLimitItem {
