@@ -13,6 +13,29 @@
 #define SECTOR_SIZE 4096
 #define ALIGN_BLOCK_SIZE(n) ((0==((n)%BLOCK_SIZE)) ? (n) : (n)+(BLOCK_SIZE-((n)%BLOCK_SIZE)))
 
+#define TIMEOUT -1 // ms
+
+
+/* ********************************************************************************************* *
+ * Implementation of OpenGD77Interface::FirmwareInfo
+ * ********************************************************************************************* */
+bool
+OpenGD77Interface::FirmwareInfo::featureInvertedDisplay() const {
+  return (qFromLittleEndian(features) & (1<<0));
+}
+
+bool
+OpenGD77Interface::FirmwareInfo::featureExtendedCallsignDB() const {
+  return (qFromLittleEndian(features) & (1<<1));
+}
+
+bool
+OpenGD77Interface::FirmwareInfo::featureVoicePromptLoaded() const {
+  return (qFromLittleEndian(features) & (1<<2));
+}
+
+
+
 /* ********************************************************************************************* *
  * Implementation of OpenGD77Interface::ReadRequest
  * ********************************************************************************************* */
@@ -62,6 +85,7 @@ bool
 OpenGD77Interface::WriteRequest::initSetFlashSector(Variant variant, uint32_t addr) {
   uint32_t sec = addr/SECTOR_SIZE;
   this->type = (Variant::GD77 == variant) ? 'W' : 'X';
+  logDebug() << "Send SET_FLASH_SECTOR (" << this->type << "): " << Qt::hex << sec << "h";
   this->command = SET_FLASH_SECTOR;
   this->sector[0] = ((sec>>16) & 0xff);
   this->sector[1] = ((sec>>8) & 0xff);
@@ -75,6 +99,7 @@ OpenGD77Interface::WriteRequest::initWriteFlash(Variant variant, uint32_t addr,
     size = 32;
   this->type = (Variant::GD77 == variant) ? 'W' : 'X';
   this->command = WRITE_SECTOR_BUFFER;
+  logDebug() << "Send WRITE_FLASH_BUFFER (" << this->type << ") @ " << Qt::hex << addr << ".";
   this->payload.address = qToBigEndian(addr);
   this->payload.length = qToBigEndian(size);
   memcpy(this->payload.data, data, size);
@@ -179,7 +204,8 @@ OpenGD77Interface::CommandRequest::initSetDateTime(const QDateTime &dt) {
  * Implementation of OpenGD77Interface
  * ********************************************************************************************* */
 OpenGD77Interface::OpenGD77Interface(const USBDeviceDescriptor &descr, const ErrorStack &err, QObject *parent)
-  : USBSerial(descr, QSerialPort::Baud115200, err, parent), _sector(-1)
+  : USBSerial(descr, QSerialPort::Baud115200, err, parent), _extendedCallsignDB(false),
+  _sector(-1)
 {
   // pass...
 }
@@ -234,6 +260,8 @@ OpenGD77Interface::identifier(const ErrorStack &err) {
   case FirmwareInfo::RadioType::MD9600:
   case FirmwareInfo::RadioType::MD2017:
     _protocolVariant = Variant::UV380;
+    _extendedCallsignDB = info.featureExtendedCallsignDB() &&
+                          !info.featureVoicePromptLoaded();
   return RadioInfo::byID(RadioInfo::OpenUV380);
   }
 
@@ -241,6 +269,13 @@ OpenGD77Interface::identifier(const ErrorStack &err) {
   return RadioInfo();
 }
 
+
+bool
+OpenGD77Interface::extendedCallsignDB() const {
+  return _extendedCallsignDB;
+}
+
+
 bool
 OpenGD77Interface::write_start(uint32_t bank, uint32_t addr, const ErrorStack &err)
 {
@@ -327,7 +362,6 @@ start:
 
 bool
 OpenGD77Interface::write_finish(const ErrorStack &err) {
-  _sector = -1;
   if (0 > _sector)
     return true;
   _sector = -1;
@@ -380,8 +414,10 @@ OpenGD77Interface::read(uint32_t bank, uint32_t addr, uint8_t *data, int nbytes,
       return false;
     }
 
-    if (! ok)
+    if (! ok) {
+      errMsg(err) << "Cannot read from bank " << bank << ", addr " << Qt::hex << addr+i << "h.";
       return false;
+    }
   }
 
   return true;
@@ -401,10 +437,23 @@ OpenGD77Interface::setDateTime(const QDateTime &datetime, const ErrorStack &err)
 }
 
 bool
-OpenGD77Interface::reboot(const ErrorStack &err) {
+OpenGD77Interface::saveSettingsNotVFOs(const ErrorStack &err) {
+  logDebug() << "Send cmd SAVE_SETTINGS_NOT_VFOS.";
   return sendCommand(CommandRequest::SAVE_SETTINGS_NOT_VFOS, err);
 }
 
+bool
+OpenGD77Interface::saveSettingsAndVFOs(const ErrorStack &err) {
+  logDebug() << "Send cmd SAVE_SETTINGS_AND_VFOS.";
+  return sendCommand(CommandRequest::SAVE_SETTINGS_AND_VFOS, err);
+}
+
+bool
+OpenGD77Interface::reboot(const ErrorStack &err) {
+  logDebug() << "Send cmd REBOOT.";
+  return sendCommand(CommandRequest::REBOOT, err);
+}
+
 
 bool
 OpenGD77Interface::readEEPROM(uint32_t addr, uint8_t *data, uint16_t len, const ErrorStack &err) {
@@ -421,7 +470,7 @@ OpenGD77Interface::readEEPROM(uint32_t addr, uint8_t *data, uint16_t len, const
     return false;
   }
 
-  if (! waitForReadyRead(1000)) {
+  if (! waitForReadyRead(TIMEOUT)) {
     errMsg(err) << "Cannot read from serial port: Timeout!";
     return false;
   }
@@ -463,7 +512,7 @@ OpenGD77Interface::writeEEPROM(uint32_t addr, const uint8_t *data, uint16_t len,
     return false;
   }
 
-  if (! waitForReadyRead(1000)) {
+  if (! waitForReadyRead(TIMEOUT)) {
     errMsg(err) << "Cannot read from serial port: Timeout!";
     return false;
   }
@@ -479,7 +528,7 @@ OpenGD77Interface::writeEEPROM(uint32_t addr, const uint8_t *data, uint16_t len,
   }
 
   if ((req.type != resp.type) || (req.command != resp.command)) {
-    errMsg(err) << "Cannot write EEPROM at " << QString::number(addr, 16)
+    errMsg(err) << "Cannot write EEPROM at " << Qt::hex << addr
              << ": Device returned error " << resp.type << ".";
     return false;
   }
@@ -505,7 +554,7 @@ OpenGD77Interface::readFlash(uint32_t addr, uint8_t *data, uint16_t len, const E
     return false;
   }
 
-  if (! waitForReadyRead(1000)) {
+  if (! waitForReadyRead(TIMEOUT)) {
     errMsg(err) << QSerialPort::errorString();
     errMsg(err) << "Cannot read from serial port: Timeout!";
     return false;
@@ -549,7 +598,7 @@ OpenGD77Interface::setFlashSector(uint32_t addr, const ErrorStack &err) {
     return false;
   }
 
-  if (! waitForReadyRead(1000)) {
+  if (! waitForReadyRead(TIMEOUT)) {
     errMsg(err) << QSerialPort::errorString();
     errMsg(err) << "Cannot read from serial port: Timeout!";
     return false;
@@ -585,7 +634,7 @@ OpenGD77Interface::writeFlash(uint32_t addr, const uint8_t *data, uint16_t len,
     return false;
   }
 
-  if (! waitForReadyRead(1000)) {
+  if (! waitForReadyRead(TIMEOUT)) {
     errMsg(err) << QSerialPort::errorString();
     errMsg(err) << "Cannot read from serial port: Timeout!";
     return false;
@@ -616,6 +665,7 @@ OpenGD77Interface::finishWriteFlash(const ErrorStack &err) {
   //logDebug() << "Send finish write flash command ...";
   WriteRequest req;
   req.initFinishWriteFlash(_protocolVariant);
+  logDebug() << "Send cmd WRITE_FLASH_SECTOR.";
   WriteResponse resp;
 
   if ((2) != QSerialPort::write((const char *)&req, 2)) {
@@ -623,7 +673,7 @@ OpenGD77Interface::finishWriteFlash(const ErrorStack &err) {
     return false;
   }
 
-  if (! waitForReadyRead(1000)) {
+  if (! waitForReadyRead(TIMEOUT)) {
     errMsg(err) << "Cannot read from serial port: Timeout!";
     return false;
   }
@@ -657,7 +707,7 @@ OpenGD77Interface::readFirmwareInfo(OpenGD77Interface::FirmwareInfo &radioInfo,
     return false;
   }
 
-  if (! waitForReadyRead(1000)) {
+  if (! waitForReadyRead(TIMEOUT)) {
     errMsg(err) << "Cannot read from serial port: Timeout!";
     return false;
   }
@@ -694,7 +744,7 @@ OpenGD77Interface::sendShowCPSScreen(const ErrorStack &err) {
     return false;
   }
 
-  if (! waitForReadyRead(1000)) {
+  if (! waitForReadyRead(TIMEOUT)) {
     errMsg(err) << "Cannot read from serial port: Timeout!";
     return false;
   }
@@ -726,7 +776,7 @@ OpenGD77Interface::sendClearScreen(const ErrorStack &err) {
     return false;
   }
 
-  if (! waitForReadyRead(1000)) {
+  if (! waitForReadyRead(TIMEOUT)) {
     errMsg(err) << "Cannot read from serial port: Timeout!";
     return false;
   }
@@ -759,7 +809,7 @@ OpenGD77Interface::sendDisplay(uint8_t x, uint8_t y, const char *message, uint8_
     return false;
   }
 
-  if (! waitForReadyRead(1000)) {
+  if (! waitForReadyRead(TIMEOUT)) {
     errMsg(err) << "Cannot read from serial port: Timeout!";
     return false;
   }
@@ -790,7 +840,7 @@ OpenGD77Interface::sendRenderCPS(const ErrorStack &err) {
     return false;
   }
 
-  if (! waitForReadyRead(1000)) {
+  if (! waitForReadyRead(TIMEOUT)) {
     errMsg(err) << "Cannot read from serial port: Timeout!";
     return false;
   }
@@ -822,7 +872,7 @@ OpenGD77Interface::sendCloseScreen(const ErrorStack &err) {
     return false;
   }
 
-  if (! waitForReadyRead(1000)) {
+  if (! waitForReadyRead(TIMEOUT)) {
     errMsg(err) << "Cannot read from serial port: Timeout!";
     return false;
   }
@@ -854,7 +904,7 @@ OpenGD77Interface::sendSetDateTime(const QDateTime &dt, const ErrorStack &err) {
     return false;
   }
 
-  if (! waitForReadyRead(1000)) {
+  if (! waitForReadyRead(TIMEOUT)) {
     errMsg(err) << "Cannot read from serial port: Timeout!";
     return false;
   }
@@ -886,7 +936,7 @@ OpenGD77Interface::sendCommand(CommandRequest::Option option, const ErrorStack &
     return false;
   }
 
-  if (! waitForReadyRead(1000)) {
+  if (! waitForReadyRead(TIMEOUT)) {
     errMsg(err) << "Cannot read from serial port: Timeout!";
     return false;
   }
