@@ -5,6 +5,7 @@
 #include <QFile>
 #include <QDir>
 #include <QNetworkReply>
+#include <QtConcurrent>
 #include <algorithm>
 #include "logger.hh"
 #include <cmath>
@@ -48,14 +49,20 @@ UserDatabase::User::distance(unsigned id) const {
 /* ********************************************************************************************* *
  * Implementation of UserDatabase
  * ********************************************************************************************* */
-UserDatabase::UserDatabase(unsigned updatePeriodDays, QObject *parent)
+UserDatabase::UserDatabase(bool parallel, unsigned updatePeriodDays, QObject *parent)
   : QAbstractTableModel(parent), _user(), _network()
 {
   connect(&_network, SIGNAL(finished(QNetworkReply*)),
           this, SLOT(downloadFinished(QNetworkReply*)));
 
-  if ((! load()) || (updatePeriodDays < dbAge()))
+  if ((! exists()) || (updatePeriodDays < dbAge()))
     download();
+  else {
+    if (parallel)
+      _parsing = QtConcurrent::run([this]() { return this->load(); });
+    else
+      load();
+  }
 }
 
 qint64
@@ -63,6 +70,18 @@ UserDatabase::count() const {
   return _user.size();
 }
 
+bool
+UserDatabase::exists() const {
+  QString path = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
+  QFileInfo info(path + "/user.json");
+  return info.isFile() && info.isReadable();
+}
+
+bool
+UserDatabase::ready() const {
+  return ! _user.empty();
+}
+
 bool
 UserDatabase::load() {
   QString path = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
@@ -115,7 +134,7 @@ UserDatabase::load(const QString &filename) {
   }
 
   beginResetModel();
-  _user.clear();
+  _user.clear(); emit readyChanged(false);
 
   QJsonArray array = doc.object()["users"].toArray();
   _user.reserve(array.size());
@@ -131,6 +150,8 @@ UserDatabase::load(const QString &filename) {
 
   logDebug() << "Loaded user database with " << _user.size() << " entries from " << filename << ".";
 
+  if (ready())
+    emit readyChanged(ready());
   emit loaded();
   return true;
 }
